import { Component, Prop, Vue } from 'vue-property-decorator';
import { Measure, MeasureConfig, Measurement, MeasurementMeta } from '@/models';

@Component
export class SimpleSummaryGraph extends Vue {
  @Prop() private measure!: Measure<MeasureConfig>;
  @Prop() private measurements!: Array<Measurement<MeasurementMeta>>;

  private chartOptions = {
    chart: { sparkline: { enabled: true } },
    grid: { padding: { top: 20 }},
    stroke: { curve: 'smooth' },
    noData: { text: 'no data',
              style: { fontSize: '18px' } },
    xaxis: { type: 'datetime' }
  };

  private get measurementData(): ApexAxisChartSeries {
    let measurementData = this.measurements.slice() || [];

    return [{
      name: this.measure.name,
      data: measurementData
        .sort((a, b) => a.timestamp.getTime() - b.timestamp.getTime())
        .map((m) => ({ x: m.timestamp.toISOString(), y: m.value }))
    }];
  }
}

export default SimpleSummaryGraph;
