import { Route } from 'vue-router';
import { Component, Prop, Vue, Watch } from 'vue-property-decorator';
import { LoginSubmit } from '@/models';
import { authStore } from '@/store';
import { logService } from '@/services/logging';

const logger = logService.getLogger('/views/login');

@Component({})
export class Login extends Vue {

  private loginForm: LoginSubmit = {
    email: '',
    password: ''
  };

  private waiting = false;
  private flashMessage = '';
  @Prop() private redirect!: string | null;

  public async login() {
    this.waiting = true;
    this.flashMessage = '';
    try {
      await authStore.login(this.loginForm);
      this.$router.push({ path: this.redirect || '/' });
    } catch (e) {
      if (e.response && e.response.status === 401) {
        this.flashMessage = 'invlid username or password';
      } else {
        this.flashMessage = 'unable to log you in';
        logger.error(e);
      }
    }
    this.waiting = false;
  }
}

// TODO: styling of flash message

export default Login;
